// (C) 2007-2024 GoodData Corporation
import * as React from "react";
import isEqual from "lodash/isEqual.js";
/**
 * Safely parse JSON string, fallback to default value if parsing fails.
 */
const safeParse = (item, defaultValue) => {
    if (!item) {
        return defaultValue;
    }
    try {
        return JSON.parse(item);
    }
    catch {
        return defaultValue;
    }
};
/**
 * Hook for using local storage.
 * Ideally, you want to keep initial value immutable to avoid unnecessary re-renders.
 * @public
 */
export const useLocalStorage = (key, initialValue) => {
    const [storedValue, setStoredValue] = React.useState(() => {
        return safeParse(localStorage.getItem(key), initialValue);
    });
    // Expose a separate callback to the user instead of using effect on storedValue
    // to avoid unnecessary localStorage writes.
    const setValue = React.useCallback((value) => {
        setStoredValue(value);
        localStorage.setItem(key, JSON.stringify(value));
    }, [key, setStoredValue]);
    // Listen to storage change events in case the value is changed in another tab or by another component.
    React.useEffect(() => {
        const handleStorageChange = (event) => {
            if (event.key !== key)
                return;
            setStoredValue((value) => {
                if (isEqual(event.newValue, value)) {
                    // Return the same value to avoid re-renders
                    return value;
                }
                return safeParse(event.newValue, initialValue);
            });
        };
        window.addEventListener("storage", handleStorageChange);
        return () => {
            window.removeEventListener("storage", handleStorageChange);
        };
    }, [key, setStoredValue, initialValue]);
    return [storedValue, setValue];
};
//# sourceMappingURL=useLocalStorage.js.map